#ifndef __GLOBDEFS_H
#define __GLOBDEFS_H

typedef enum 
{
  BAT_POWER = 0,
  BAT_MOTOR = 1,
  EXT_POWER = 2,
  EXT_MOTOR = 3,
  CHARGING  = 6,
  POWER_ON  = 7,
  SLEEP	    = 8
} 
  TSTATE;

typedef enum 
{
  NO_ERROR, 
  OVER_VOLT_ERROR, 
  TIMEOUT_ERROR,
  CHARGE_COMPLETED_WELL
} 
  TERROR;
  
typedef enum {LED_OFF, LED_BLINK, LED_ON};
  
#define LED_PORT PRT1DR
#define LED_BIT  4

#define BUTTON_PORT PRT1DR
#define BUTTON_BIT 2

#define VC3_TIME_INTERVAL 600

#define MOTOR_PORT PRT1DR
#define MOTOR_BIT 3
#define MOTOR_ON() SETBIT(MOTOR_PORT, MOTOR_BIT)
#define MOTOR_OFF() CLEARBIT(MOTOR_PORT, MOTOR_BIT)

#define BAT_CNTR_PORT PRT1DR
#define BAT_CNTR_BIT  6
#define BAT_ON() SETBIT(BAT_CNTR_PORT, BAT_CNTR_BIT)
#define BAT_OFF() CLEARBIT(BAT_CNTR_PORT, BAT_CNTR_BIT)

#define MAINS_POWER_PORT PRT1DR
#define MAINS_POWER_BIT  5

#define DUTY_MIN 0
#define DUTY_MAX 255

#define DIF_DELTA 10

#define DIF1 240
#define DIF2 50
#define DIF3 15

#define STEP1 20
#define STEP2 4
#define STEP3 2

#define FILTER_SETUP  2

#define TEMP_HIGH_OFF 100
#define TEMP_HIGH_ON  120
#define TEMP_LOW_ON   950
#define TEMP_LOW_OFF  970

#define Rdiv (300.0/710.0)
#define Uref 2.6
#define ADC_RANGE 2048.0
#define ADC_SCALE_FACTOR_VOLT  (Rdiv*ADC_RANGE/Uref)

#define CELLS 2.0
#define BAT_VOLT_CHARGE_START_VOLT 1.15
#define BAT_VOLT_MOTOR_STOP_VOLT 0.9
#define BAT_VOLT_OVER_VOLT 1.8

#define BAT_VOLT_CHARGE_START ((INT)(CELLS*BAT_VOLT_CHARGE_START_VOLT*ADC_SCALE_FACTOR_VOLT))
#define BAT_VOLT_MOTOR_STOP ((INT)(CELLS*BAT_VOLT_MOTOR_STOP_VOLT*ADC_SCALE_FACTOR_VOLT))
#define BAT_VOLT_OVER ((INT)(CELLS*BAT_VOLT_OVER_VOLT*ADC_SCALE_FACTOR_VOLT))

#define MOTOR_VOLTAGE_EXT_POW_VOLT 2.7
#define MOTOR_VOLTAGE_EXT_POW ((WORD)(MOTOR_VOLTAGE_EXT_POW_VOLT*ADC_SCALE_FACTOR_VOLT))

#define RSense 0.1
#define LPF_GAIN  10.75
#define ADC_SCALE_FACTOR_AMP (RSense*LPF_GAIN*ADC_RANGE/Uref)

#define BAT_CURRENT_RAPID_AMP 1
#define BAT_CURRENT_TRICLE_AMP 0.1
#define SUPPLY_CURRENT_AMP 0.02

#define SUPPLY_CURRENT ((INT)(ADC_SCALE_FACTOR_AMP*SUPPLY_CURRENT_AMP))
#define BAT_CURRENT_RAPID ((INT)(ADC_SCALE_FACTOR_AMP*BAT_CURRENT_RAPID_AMP))
#define BAT_CURRENT_TRICLE ((INT)(ADC_SCALE_FACTOR_AMP*BAT_CURRENT_TRICLE_AMP))


#define MOTOR_MAX_CURRENT_AMP 1.0
#define MOTOR_MAX_CURRENT ((INT)(ADC_SCALE_FACTOR_AMP*MOTOR_MAX_CURRENT_AMP))

#define TIME_BAT_VOLT_AND_TEMP 4
#define TIME_TOTAL_CHARGE 7200
#define TIME_STARTUP_DELAY 300

#define TIME_DELAY_TO_SLEEP 2

#define DEBUG 1

#endif
